############
Installation
############

From PyPI
---------

.. code-block:: bash

    pip install -U litegram

From Arch Linux Repository
--------------------------

.. warning:: Package in this repository may be outdated. Use PyPI package for the latest version.

.. code-block:: bash

    pacman -S python-litegram

Development build
=================

From GitHub
-----------

.. code-block:: bash

    pip install https://github.com/litegram/litegram/archive/refs/heads/dev-3.x.zip
